<?php

namespace Classifieds\Feature\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Classifieds\Feature\Actions\FeatureAction;
use Classifieds\Feature\Http\Requests\FeatureActionRequest;
use Classifieds\Feature\Http\Resources\FeatureResource;
use Classifieds\Feature\Models\Feature;

/**
 * Admin web controller class.
 */
class FeatureActionController extends BaseController
{

    /**
     * Action controller function for feature.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(FeatureActionRequest $request, Feature $feature, $action)
    {
        try {
            $request = $request->all();
            $feature = FeatureAction::run($action, $feature, $request);

            $data = new FeatureResource($feature);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('feature::feature.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('feature/feature/' . $feature->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('feature/feature/' . $feature->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
