<?php

namespace Classifieds\Feature\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Exception;
use Classifieds\Feature\Http\Requests\FeatureActionsRequest;
use Classifieds\Feature\Actions\FeatureActions;

/**
 * Admin web controller class.
 */
class FeatureActionsController extends BaseController
{

    /**
     * Action controller function for feature.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(FeatureActionsRequest $request, $action)
    {
        try {
            $feature = FeatureActions::run($request, $action);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('feature::feature.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('feature/feature/' . $action))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('feature/feature/' . $action))
                ->redirect();
        }
    }
}
