<?php

namespace Classifieds\Feature\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Classifieds\Feature\Events\FeatureAction as FeatureActionEvent;
use Classifieds\Feature\Notifications\FeatureAction as FeatureActionNotification;
use Litepie\Actions\Concerns\AsAction;

class FeatureAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the FeatureActionEvent.
     *
     * @param   FeatureActionEvent  $event
     * @return mixed
     */
    public function handle(FeatureActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $feature.
     *
     * @param   FeatureActionEvent  $event
     * @return void
     */
    public function create(FeatureActionEvent $event)
    {
        $client = $event->feature->client;
        Notification::send($client, new FeatureActionNotification($event));
    }

    /**
     * Handle the FeatureActionEvent as a listener.
     *
     * @param   FeatureActionEvent  $event
     * @return mixed
     */
    public function asListener(FeatureActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   FeatureActionEvent  $event
     * @return bool
     */
    private function isAllowed(FeatureActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
