<?php
namespace Classifieds\Feature\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Classifieds\Feature\Events\FeatureAction as FeatureActionEvent;
use Classifieds\Feature\Models\Feature;

class FeatureAction extends Notification implements ShouldQueue
{
    use Queueable;

    protected $event;
    protected $feature;
    protected $action;
    protected $request;

    /**
     * Create a new notification instance.
     *
     * @param FeatureActionEvent $feature
     */
    public function __construct(FeatureActionEvent $feature)
    {
        $this->action = $event->action;
        $this->feature = $feature;
        $this->request = $event->request;
        $this->event = $event;

    }

    /**
     * Get the mail representation of the notification.
     *
     * @param mixed $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('Feature Approved - ' . config('app.name'))
            ->view('feature::feature.email.action', ['data' => $this->feature]);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param object $notifiable
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }
}
