<?php

namespace Classifieds\Feature\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Classifieds\Feature\Models\Feature;

class FeaturePolicy
{

    use FeatureAction;
    use FeatureWorkflow;

    /**
     * Determine if the given user can view the feature.
     *
     * @param Authenticatable $user
     * @param Feature $feature
     *
     * @return bool
     */
    public function view(Authenticatable $user, Feature $feature)
    {
        if ($authUser->canDo('feature.feature.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $feature->is_owner;
    }

    /**
     * Determine if the given user can create a feature.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('feature.feature.create');
    }

    /**
     * Determine if the given user can update the given feature.
     *
     * @param Authenticatable $user
     * @param Feature $feature
     *
     * @return bool
     */
    public function update(Authenticatable $user, Feature $feature)
    {
        if ($user->canDo('feature.feature.edit') && $user->isAdmin()) {
            return true;
        }

        return $feature->is_owner;
    }

    /**
     * Determine if the given user can delete the given feature.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Feature $feature)
    {
        return $feature->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
